"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports["default"] = getArrayType;
exports.ArrayType = void 0;

var _assertThisInitialized2 = _interopRequireDefault(require("@babel/runtime/helpers/assertThisInitialized"));

var _inheritsLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/inheritsLoose"));

var _MixedType2 = require("./MixedType");

var ArrayType = /*#__PURE__*/function (_MixedType) {
  (0, _inheritsLoose2["default"])(ArrayType, _MixedType);

  function ArrayType(errorMessage) {
    var _this;

    _this = _MixedType.call(this, 'array') || this;

    _MixedType.prototype.pushRule.call((0, _assertThisInitialized2["default"])(_this), function (v) {
      return Array.isArray(v);
    }, errorMessage || 'Please enter a valid array');

    return _this;
  }

  var _proto = ArrayType.prototype;

  _proto.rangeLength = function rangeLength(minLength, maxLength, errorMessage) {
    _MixedType.prototype.pushRule.call(this, function (value) {
      return value.length >= minLength && value.length <= maxLength;
    }, errorMessage);

    return this;
  };

  _proto.minLength = function minLength(_minLength, errorMessage) {
    _MixedType.prototype.pushRule.call(this, function (value) {
      return value.length >= _minLength;
    }, errorMessage);

    return this;
  };

  _proto.maxLength = function maxLength(_maxLength, errorMessage) {
    _MixedType.prototype.pushRule.call(this, function (value) {
      return value.length <= _maxLength;
    }, errorMessage);

    return this;
  };

  _proto.unrepeatable = function unrepeatable(errorMessage) {
    _MixedType.prototype.pushRule.call(this, function (items) {
      var hash = {};

      for (var i in items) {
        if (hash[items[i]]) {
          return false;
        }

        hash[items[i]] = true;
      }

      return true;
    }, errorMessage);

    return this;
  }
  /**
   * @example
   * ArrayType().of(StringType().isOneOf(['数码','体育','游戏','旅途','其他'],'Can only be the value of a predefined option')
   */
  ;

  _proto.of = function of(type, errorMessage) {
    _MixedType.prototype.pushRule.call(this, function (items) {
      var checkResults = items.map(function (value) {
        return type.check(value);
      });
      var hasError = !!checkResults.find(function (item) {
        return item === null || item === void 0 ? void 0 : item.hasError;
      });
      return {
        hasError: hasError,
        array: checkResults
      };
    }, errorMessage);

    return this;
  };

  return ArrayType;
}(_MixedType2.MixedType);

exports.ArrayType = ArrayType;

function getArrayType(errorMessage) {
  return new ArrayType(errorMessage);
}