import { SchemaDeclaration, CheckResult, ValidCallbackType, RuleType } from './types';
export declare class MixedType<ValueType = any, DataType = any, ErrorMsgType = string> {
    readonly name?: string;
    protected required: boolean;
    protected requiredMessage: ErrorMsgType | string;
    protected trim: boolean;
    protected emptyAllowed: boolean;
    protected rules: RuleType<ValueType, DataType, ErrorMsgType | string>[];
    protected priorityRules: RuleType<ValueType, DataType, ErrorMsgType | string>[];
    schemaSpec: SchemaDeclaration<DataType, ErrorMsgType>;
    value: any;
    constructor(name?: string);
    setSchemaOptions(schemaSpec: SchemaDeclaration<DataType, ErrorMsgType>, value: any): void;
    check(value?: ValueType, data?: DataType): CheckResult<string | ErrorMsgType>;
    checkAsync(value?: ValueType, data?: DataType): Promise<CheckResult<ErrorMsgType | string>>;
    protected pushRule(onValid: ValidCallbackType<ValueType, DataType, ErrorMsgType | string>, errorMessage?: ErrorMsgType | string, priority?: boolean): void;
    addRule(onValid: ValidCallbackType<ValueType, DataType, ErrorMsgType | string>, errorMessage?: ErrorMsgType | string, priority?: boolean): this;
    isRequired(errorMessage: ErrorMsgType | string, trim?: boolean): this;
    isRequiredOrEmpty(errorMessage: ErrorMsgType | string, trim?: boolean): this;
    /**
     * Define data verification rules based on conditions.
     * @param validator
     * @example
     * MixedType().when(schema => {
     *   return schema.filed1.check() ? NumberType().min(5) : NumberType().min(0);
     * });
     */
    when(condition: (schemaSpec: SchemaDeclaration<DataType, ErrorMsgType>) => MixedType): this;
}
export default function getMixedType<DataType = any, ErrorMsgType = string>(): MixedType<DataType, ErrorMsgType, string>;
