"use strict";

exports.__esModule = true;
exports.createValidatorAsync = createValidatorAsync;
exports["default"] = void 0;

/**
 * Create a data asynchronous validator
 * @param data
 */
function createValidatorAsync(data) {
  function check(errorMessage) {
    return function (checkResult) {
      if (checkResult === false) {
        return {
          hasError: true,
          errorMessage: errorMessage
        };
      } else if (typeof checkResult === 'object' && (checkResult.hasError || checkResult.array)) {
        return checkResult;
      }

      return null;
    };
  }

  return function (value, rules) {
    var promises = rules.map(function (rule) {
      var onValid = rule.onValid,
          errorMessage = rule.errorMessage;
      return Promise.resolve(onValid(value, data)).then(check(errorMessage));
    });
    return Promise.all(promises).then(function (results) {
      return results.find(function (item) {
        return item && (item === null || item === void 0 ? void 0 : item.hasError);
      });
    });
  };
}

var _default = createValidatorAsync;
exports["default"] = _default;